pycocoa.colors

Package pycocoa :: Module colors |
[frames] | no frames]

# Module colors

Types Color, ColorError, CMYColor, GrayScaleColor, HSBColor, RGBColor, TintColor and UIColor wrapping Cocoa's `NSColor` and `enum`-like constants CMYColors, GrayScaleColors, HSBColors, RGBColors, TintColor, TintColors, UIColors and all Colors accessible by color space acronym like `CMY`, `GS`, `RGB`, etc.

Version: 21.11.04

Classes
| ColorError `Color` issue.
| Color Base `Color` class wrapping `NSColor` objects, intended specifically to avoid fatal exceptions when accessing non-applicable `NSColor` attributes.
| CMYColor Color in the Cyan-Magenta-Yellow space.
| GrayScaleColor Color in the Gray-Scale space.
| HSBColor Color in thecHue-Saturation-Brightness space.
| RGBColor Color in the Red-Green-Blue space.
| TintColor Dynamic color, adaptable to vibrancy and accessibility settings.
| UIColor Dynamic color for User-Interface elements, adaptable to vibrancy and accessibility settings.

Variables
| __all__ = `_ALL_LAZY.colors`
| CMYColors = `CMYColors.Cyan=CMYColor(_NSTaggedPointerColor, nam`...`` Some standard `Cyan-Magenta-Yellow` colors, all CMYColor instances (`enum`).
| GrayScaleColors = `GrayScaleColors.Black=GrayScaleColor(_NSTagg`...`` Some standard `Gray-Scale` colors, all GrayScaleColor instances (`enum`).
| HSBColors = `HSBColors.NoneYet=None` No standard `Hue-Saturation-Brightness` colors, HSBColor instances (`enum`).
| RGBColors = `RGBColors.Blue=RGBColor(_NSTaggedPointerColor, nam`...`` Some standard `Red-Green-Blue` colors, all RGBColor instances (`enum`).
| TintColors = `TintColors.Blue=TintColor(NSDynamicSystemColor, n`...`` Some dynamic tints, adaptable to vibrancy and accessibility settings, all TintColor instances (`enum`).
| UIColors = `UIColors.Control=UIColor(NSDynamicSystemColor, name`...`` Some dynamic UI element colors, adaptable to vibrancy and accessibility settings, all UIColor instances (`enum`).
| Colors = `Colors.CMY=CMYColo`...`` Colors by color space acronym, like `Colors.RGB.Red`, `Colors.Tint.Red` (`enum`).
| CMYColors.Cyan Color in the Cyan-Magenta-Yellow space.
| CMYColors.Magenta Color in the Cyan-Magenta-Yellow space.
| CMYColors.Yellow Color in the Cyan-Magenta-Yellow space.
| Colors.CMY Some standard `Cyan-Magenta-Yellow` colors, all CMYColor instances (`enum`).
| Colors.GS Some standard `Gray-Scale` colors, all GrayScaleColor instances (`enum`).
| Colors.HSB No standard `Hue-Saturation-Brightness` colors, HSBColor instances (`enum`).
| Colors.RGB Some standard `Red-Green-Blue` colors, all RGBColor instances (`enum`).
| Colors.Tint Some dynamic tints, adaptable to vibrancy and accessibility settings, all TintColor instances (`enum`).
| Colors.UI Some dynamic UI element colors, adaptable to vibrancy and accessibility settings, all UIColor instances (`enum`).
| GrayScaleColors.Black Color in the Gray-Scale space.
| GrayScaleColors.Clear Color in the Gray-Scale space.
| GrayScaleColors.DarkGray Color in the Gray-Scale space.
| GrayScaleColors.Gray Color in the Gray-Scale space.
| GrayScaleColors.LightGray Color in the Gray-Scale space.
| GrayScaleColors.Tansparent Color in the Gray-Scale space.
| GrayScaleColors.White Color in the Gray-Scale space.
| HSBColors.NoneYet .
| RGBColors.Blue Color in the Red-Green-Blue space.
| RGBColors.Brown Color in the Red-Green-Blue space.
| RGBColors.Green Color in the Red-Green-Blue space.
| RGBColors.Orange Color in the Red-Green-Blue space.
| RGBColors.Purple Color in the Red-Green-Blue space.
| RGBColors.Red Color in the Red-Green-Blue space.
| TintColors.Blue Dynamic color, adaptable to vibrancy and accessibility settings.
| TintColors.Brown Dynamic color, adaptable to vibrancy and accessibility settings.
| TintColors.Gray Dynamic color, adaptable to vibrancy and accessibility settings.
| TintColors.Green Dynamic color, adaptable to vibrancy and accessibility settings.
| TintColors.Indigo Dynamic color, adaptable to vibrancy and accessibility settings.
| TintColors.Orange Dynamic color, adaptable to vibrancy and accessibility settings.
| TintColors.Pink Dynamic color, adaptable to vibrancy and accessibility settings.
| TintColors.Purple Dynamic color, adaptable to vibrancy and accessibility settings.
| TintColors.Red Dynamic color, adaptable to vibrancy and accessibility settings.
| TintColors.Teal Dynamic color, adaptable to vibrancy and accessibility settings.
| TintColors.Yellow Dynamic color, adaptable to vibrancy and accessibility settings.
| UIColors.Control Dynamic color for User-Interface elements, adaptable to vibrancy and accessibility settings.
| UIColors.ControlBackground Dynamic color for User-Interface elements, adaptable to vibrancy and accessibility settings.
| UIColors.Grid Dynamic color for User-Interface elements, adaptable to vibrancy and accessibility settings.
| UIColors.HeaderText Dynamic color for User-Interface elements, adaptable to vibrancy and accessibility settings.
| UIColors.Highlight Dynamic color for User-Interface elements, adaptable to vibrancy and accessibility settings.
| UIColors.Label Dynamic color for User-Interface elements, adaptable to vibrancy and accessibility settings.
| UIColors.Link Dynamic color for User-Interface elements, adaptable to vibrancy and accessibility settings.
| UIColors.SelectedText Dynamic color for User-Interface elements, adaptable to vibrancy and accessibility settings.
| UIColors.Separator Dynamic color for User-Interface elements, adaptable to vibrancy and accessibility settings.
| UIColors.Shadow Dynamic color for User-Interface elements, adaptable to vibrancy and accessibility settings.
| UIColors.Text Dynamic color for User-Interface elements, adaptable to vibrancy and accessibility settings.
| UIColors.WindowBackground Dynamic color for User-Interface elements, adaptable to vibrancy and accessibility settings.

Variables Details

  ### CMYColors Some standard `Cyan-Magenta-Yellow` colors, all CMYColor instances (`enum`). Value:
      CMYColors.Cyan=CMYColor(_NSTaggedPointerColor, name='Cyan'),
               .Magenta=CMYColor(_NSTaggedPointerColor, name='Magenta'),
               .Yellow=CMYColor(_NSTaggedPointerColor, name='Yellow')

  ### GrayScaleColors Some standard `Gray-Scale` colors, all GrayScaleColor instances (`enum`). Value:
      GrayScaleColors.Black=GrayScaleColor(_NSTaggedPointerColor, name='Blac
      k'),
                     .Clear=GrayScaleColor(_NSTaggedPointerColor, name='Clea
      r'),
                     .DarkGray=GrayScaleColor(_NSTaggedPointerColor, name='D
      arkGray'),
                     .Gray=GrayScaleColor(_NSTaggedPointerColor, name='Gray'
      ),
      ...

  ### RGBColors Some standard `Red-Green-Blue` colors, all RGBColor instances (`enum`). Value:
      RGBColors.Blue=RGBColor(_NSTaggedPointerColor, name='Blue'),
               .Brown=RGBColor(_NSTaggedPointerColor, name='Brown'),
               .Green=RGBColor(_NSTaggedPointerColor, name='Green'),
               .Orange=RGBColor(NSCachedRGBColor, name='Orange'),
               .Purple=RGBColor(NSCachedRGBColor, name='Purple'),
               .Red=RGBColor(_NSTaggedPointerColor, name='Red')

  ### TintColors Some dynamic tints, adaptable to vibrancy and accessibility settings, all TintColor instances (`enum`). Value:
      TintColors.Blue=TintColor(NSDynamicSystemColor, name='Blue'),
                .Brown=TintColor(NSDynamicSystemColor, name='Brown'),
                .Gray=TintColor(NSDynamicSystemColor, name='Gray'),
                .Green=TintColor(NSDynamicSystemColor, name='Green'),
                .Indigo=TintColor(NSDynamicSystemColor, name='Indigo'),
                .Orange=TintColor(NSDynamicSystemColor, name='Orange'),
                .Pink=TintColor(NSDynamicSystemColor, name='Pink'),
                .Purple=TintColor(NSDynamicSystemColor, name='Purple'),
      ...

  ### UIColors Some dynamic UI element colors, adaptable to vibrancy and accessibility settings, all UIColor instances (`enum`). Value:
      UIColors.Control=UIColor(NSDynamicSystemColor, name='Control'),
              .ControlBackground=UIColor(NSDynamicSystemColor, name='Control
      Background'),
              .Grid=UIColor(NSDynamicSystemColor, name='Grid'),
              .HeaderText=UIColor(NSDynamicSystemColor, name='HeaderText'),
              .Highlight=UIColor(NSDynamicSystemColor, name='Highlight'),
              .Label=UIColor(NSDynamicSystemColor, name='Label'),
              .Link=UIColor(NSDynamicSystemColor, name='Link'),
      ...

  ### Colors Colors by color space acronym, like `Colors.RGB.Red`, `Colors.Tint.Red` (`enum`). Value:
      Colors.CMY=CMYColors,
            .GS=GrayScaleColors,
            .HSB=HSBColors,
            .RGB=RGBColors,
            .Tint=TintColors,
            .UI=UIColors